@@ -112,7 +112,7 @@ namespace libtorrent
 			optimize_alignment = 1,
 #ifndef TORRENT_NO_DEPRECATE
 			// same as optimize_alignment, for backwards compatibility
-			optimize = 1,
+			optimize TORRENT_DEPRECATED_ENUM = 1,
 #endif
 
 			// This will create a merkle hash tree torrent. A merkle torrent cannot
@@ -170,10 +170,13 @@ namespace libtorrent
 		// ``alignment`` is used when pad files are enabled. This is the size
 		// eligible files are aligned to. The default is -1, which means the
 		// piece size of the torrent.
+		// The ``use_preformatted`` parameter can be set to true to preserve
+		// invalid encoding of the .torrent file.
 		create_torrent(file_storage& fs, int piece_size = 0
 			, int pad_file_limit = -1, int flags = optimize_alignment
 			, int alignment = -1);
 		create_torrent(torrent_info const& ti);
+		create_torrent(torrent_info const& ti, bool use_preformatted);
 
 		// internal
 		~create_torrent();
@@ -298,6 +301,8 @@ namespace libtorrent
 
 	private:
 
+		void load_from_torrent_info(torrent_info const& ti, bool const use_preformatted);
+
 		file_storage& m_files;
 		// if m_info_dict is initialized, it is
 		// used instead of m_files to generate
@@ -438,16 +443,16 @@ namespace libtorrent
 	// and pass in utf8 strings
 #ifndef TORRENT_NO_DEPRECATE
 
-	TORRENT_DEPRECATED
-	TORRENT_EXPORT void add_files(file_storage& fs, std::wstring const& wfile
+	TORRENT_DEPRECATED_EXPORT
+	void add_files(file_storage& fs, std::wstring const& wfile
 		, boost::function<bool(std::string)> p, boost::uint32_t flags = 0);
 
-	TORRENT_DEPRECATED
-	TORRENT_EXPORT void add_files(file_storage& fs, std::wstring const& wfile
+	TORRENT_DEPRECATED_EXPORT
+	void add_files(file_storage& fs, std::wstring const& wfile
 		, boost::uint32_t flags = 0);
 	
-	TORRENT_DEPRECATED
-	TORRENT_EXPORT void set_piece_hashes(create_torrent& t, std::wstring const& p
+	TORRENT_DEPRECATED_EXPORT
+	void set_piece_hashes(create_torrent& t, std::wstring const& p
 		, boost::function<void(int)> f, error_code& ec);
 
 	TORRENT_EXPORT void set_piece_hashes_deprecated(create_torrent& t
