@@ -41,6 +41,7 @@ POSSIBILITY OF SUCH DAMAGE.
 #include <set>
 
 #include <boost/shared_ptr.hpp>
+#include <boost/make_shared.hpp>
 #include <boost/function.hpp>
 #include <boost/weak_ptr.hpp>
 #include <boost/cstdint.hpp>
@@ -82,6 +83,9 @@ namespace libtorrent
 	void throw_invalid_handle() TORRENT_NO_RETURN;
 #endif
 
+	using boost::shared_ptr;
+	using boost::make_shared;
+
 	// holds the state of a block in a piece. Who we requested
 	// it from and how far along we are at downloading it.
 	struct TORRENT_EXPORT block_info
@@ -832,6 +836,11 @@ namespace libtorrent
 		void queue_position_top() const;
 		void queue_position_bottom() const;
 
+		// updates the position in the queue for this torrent. The relative order
+		// of all other torrents remain intact but their numerical queue position
+		// shifts to make space for this torrent's new position
+		void queue_position_set(int p) const;
+
 #ifndef TORRENT_NO_DEPRECATE
 		// deprecated in 1.1
 
@@ -896,7 +905,7 @@ namespace libtorrent
 		// without metadata only if it was started without a .torrent file, e.g.
 		// by using the libtorrent extension of just supplying a tracker and
 		// info-hash.
-		boost::shared_ptr<const torrent_info> torrent_file() const;
+		shared_ptr<const torrent_info> torrent_file() const;
 
 #ifndef TORRENT_NO_DEPRECATE
 
@@ -972,8 +981,6 @@ namespace libtorrent
 		// will return the resume data in an alert
 		TORRENT_DEPRECATED
 		entry write_resume_data() const;
-		// ================ end deprecation ============
-#endif
 
 		// ``use_interface()`` sets the network interface this torrent will use
 		// when it opens outgoing connections. By default, it uses the same
@@ -982,7 +989,10 @@ namespace libtorrent
 		// IPv4 or IPv6 address). When specifying multiple interfaces, the
 		// torrent will round-robin which interface to use for each outgoing
 		// connection. This is useful for clients that are multi-homed.
+		TORRENT_DEPRECATED
 		void use_interface(const char* net_interface) const;
+		// ================ end deprecation ============
+#endif
 
 		// Fills the specified ``std::vector<int>`` with the availability for
 		// each piece in this torrent. libtorrent does not keep track of
@@ -1000,8 +1010,10 @@ namespace libtorrent
 		// You may however change the priority of individual pieces. There are 8
 		// priority levels. 0 means not to download the piece at all. Otherwise,
 		// lower priority values means less likely to be picked. Piece priority
-		// takes precedence over piece availability. Every priority-7 piece will
-		// be attempted to be picked before a priority 6 piece and so on.
+		// takes precedence over piece availability. Every piece with priority 7
+		// will be attempted to be picked before a priority 6 piece and so on.
+		// 
+		// The default priority of pieces is 4.
 		// 
 		// Piece priorities can not be changed for torrents that have not
 		// downloaded the metadata yet. For instance, magnet links and torrents
@@ -1107,6 +1119,8 @@ namespace libtorrent
 		// 
 		// ``upload_limit`` and ``download_limit`` will return the current limit
 		// setting, for upload and download, respectively.
+		// 
+		// Local peers are not rate limited by default. see peer-classes_.
 		void set_upload_limit(int limit) const;
 		int upload_limit() const;
 		void set_download_limit(int limit) const;
